@@ -20,6 +20,10 @@ from svg_ultralight.query import (
 INKSCAPE = "C:\\Program Files\\Inkscape\\inkscape"
 
 
+aaa = BoundingBox(-2, -4, 10, 20)
+bbb = BoundingBox(3, 4, 10, 20)
+
+
 class TestMapIdsToBoundingBoxes:
     def test_gets_bboxes(self) -> None:
         """
